// $Id: Print.java 17038 2013-03-06 13:34:42Z chris $

package org.faceless.pdf2.viewer2.feature;

import org.faceless.pdf2.viewer2.*;
import org.faceless.pdf2.*;
import javax.swing.*;
import javax.print.*;

/**
 * Create a button that opens a print dialog.
 *
 * <span class="featurename">The name of this feature is <span class="featureactualname">Print</span></span>
 * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
 * @since 2.8
 */
public class Print extends ViewerWidget implements DocumentPanelListener
{
    public Print() {
        super("Print");
        setButton("Document", "resources/icons/print.png", "PDFViewer.tt.Print");
        setMenu("File\tPrint", 'p');
    }

    public void initialize(PDFViewer viewer) {
        super.initialize(viewer);
        viewer.addDocumentPanelListener(this);
    }

    public void documentUpdated(DocumentPanelEvent event) {
        DocumentPanel docpanel = event.getDocumentPanel();
        String type = event.getType();
        if (("activated".equals(type) || "permissionChanged".equals(type)) &&
                docpanel.getPDF() != null) {
            boolean enabled = docpanel.hasPermission("Print");
            PDFViewer viewer = docpanel.getViewer();
            viewer.getNamedComponent("ButtonPrint").setEnabled(enabled);
            viewer.getNamedComponent("MenuPrint").setEnabled(enabled);
        }
    }

    public void action(ViewerEvent event) {
        try {
            event.getDocumentPanel().print(null, null);
        } catch (Exception e) {
            Util.displayThrowable(e, event.getViewer());
        }
    }
}
